@@ -1,19 +1,13 @@
-# encoding=UTF-8
-
 # Copyright © 2015-2021 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2022-2024 FriedrichFroebel
 #
-# This file is part of python-djvulibre.
+# This file is part of djvulibre-python.
 #
-# python-djvulibre is free software; you can redistribute it and/or modify it
+# djvulibre-python is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 2 as published by
 # the Free Software Foundation.
 #
-# python-djvulibre is distributed in the hope that it will be useful, but
+# djvulibre-python is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 # or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 # more details.
-
-type(b'')  # Python >= 2.6 is required
-type(u'')  # Python 2.X or >= 3.3 is required
-
-# vim:ts=4 sts=4 sts=4 sw=4 et
